==> univention-s4-connector_14.0.10-6A~5.0.0.202208301457.tar.gz: univention-s4-connector-14.0.10/scripts/remove_ucs_rejected.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
# Univention S4 Connector
#  Remove rejected UCS object
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2014-2022 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from __future__ import print_function

import os
import sys
from argparse import ArgumentParser

import univention.s4connector
import univention.uldap


class ObjectNotFound(BaseException):
	pass


def remove_ucs_rejected(ucs_dn):
	config = univention.s4connector.configdb('/etc/univention/connector/s4internal.sqlite')
	found = False
	for filename, rejected_dn in config.items('UCS rejected'):
		if univention.uldap.access.compare_dn(ucs_dn, rejected_dn):
			if os.path.exists(filename):
				os.remove(filename)
			config.remove_option('UCS rejected', filename)
			found = True

	if not found:
		raise ObjectNotFound()


if __name__ == '__main__':
	parser = ArgumentParser()
	parser.add_argument('dn')
	args = parser.parse_args()

	ucs_dn = args.dn

	try:
		remove_ucs_rejected(ucs_dn)
	except ObjectNotFound:
		print('ERROR: The object %s was not found.' % ucs_dn)
		sys.exit(1)

	print('The rejected UCS object %s has been removed.' % ucs_dn)
	sys.exit(0)

==> univention-s4-connector_14.0.13-5A~5.0.0.202304191550.tar.gz: univention-s4-connector-14.0.13/scripts/remove_ucs_rejected.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
# Univention S4 Connector
#  Remove rejected UCS object
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2014-2023 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from __future__ import print_function

import os
import sys
from argparse import ArgumentParser

import univention.s4connector
import univention.uldap


class ObjectNotFound(BaseException):
    pass


def remove_ucs_rejected(ucs_dn):
    config = univention.s4connector.configdb('/etc/univention/connector/s4internal.sqlite')
    found = False
    for filename, rejected_dn in config.items('UCS rejected'):
        if univention.s4connector.RE_NO_RESYNC.match(rejected_dn):
            if ucs_dn != rejected_dn:
                continue
        elif not univention.uldap.access.compare_dn(ucs_dn, rejected_dn):
            continue

        if os.path.exists(filename):
            os.remove(filename)
        config.remove_option('UCS rejected', filename)
        found = True

    if not found:
        raise ObjectNotFound()


if __name__ == '__main__':
    parser = ArgumentParser()
    parser.add_argument('dn')
    args = parser.parse_args()

    ucs_dn = args.dn

    try:
        remove_ucs_rejected(ucs_dn)
    except ObjectNotFound:
        print('ERROR: The object %s was not found.' % ucs_dn)
        sys.exit(1)

    print('The rejected UCS object %s has been removed.' % ucs_dn)
    sys.exit(0)
